@@ -17,6 +17,7 @@ except ImportError:
 from redis.connection import UnixDomainSocketConnection, Connection
 from redis.connection import DefaultParser
 
+
 class CacheKey(object):
     """
     A stub string class that we can use to check if a key was created already.
@@ -38,12 +39,15 @@ class CacheKey(object):
 
 
 class CacheConnectionPool(object):
-    _connection_pool = None
+
+    def __init__(self):
+        self._connection_pools = {}
 
     def get_connection_pool(self, host='127.0.0.1', port=6379, db=1,
         password=None, parser_class=None,
         unix_socket_path=None):
-        if self._connection_pool is None:
+        connection_identifier = (host, port, db, parser_class, unix_socket_path)
+        if not self._connection_pools.get(connection_identifier):
             connection_class = (
                 unix_socket_path and UnixDomainSocketConnection or Connection
             )
@@ -60,8 +64,8 @@ class CacheConnectionPool(object):
                 })
             else:
                 kwargs['path'] = unix_socket_path
-            self._connection_pool = redis.ConnectionPool(**kwargs)
-        return self._connection_pool
+            self._connection_pools[connection_identifier] = redis.ConnectionPool(**kwargs)
+        return self._connection_pools[connection_identifier]
 pool = CacheConnectionPool()
 
 
@@ -79,7 +83,7 @@ class CacheClass(BaseCache):
 
         unix_socket_path = None
         if ':' in self.server:
-            host, port = self.server.split(':')
+            host, port = self.server.rsplit(':', 1)
             try:
                 port = int(port)
             except (ValueError, TypeError):
